#ifndef NT2_INCLUDE_FUNCTIONS_FAST_COTPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FAST_COTPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/fast_cotpi.hpp>

#endif
